@@ -3,9 +3,8 @@ from __future__ import division
 import logging
 import threading
 
+import av.error
 import av.logging
-import av.utils
-from av import AVError
 
 from .common import TestCase
 
@@ -38,9 +37,7 @@ class TestLogging(TestCase):
             thread.start()
             thread.join()
 
-        self.assertEqual(logs, [
-            (av.logging.INFO, 'test', 'main'),
-        ])
+        self.assertIn((av.logging.INFO, 'test', 'main'), logs)
 
     def test_global_captures(self):
 
@@ -50,10 +47,8 @@ class TestLogging(TestCase):
             thread.start()
             thread.join()
 
-        self.assertEqual(logs, [
-            (av.logging.INFO, 'test', 'main'),
-            (av.logging.INFO, 'test', 'thread'),
-        ])
+        self.assertIn((av.logging.INFO, 'test', 'main'), logs)
+        self.assertIn((av.logging.INFO, 'test', 'thread'), logs)
 
     def test_repeats(self):
 
@@ -81,8 +76,8 @@ class TestLogging(TestCase):
         log = (av.logging.ERROR, 'test', 'This is a test.')
         av.logging.log(*log)
         try:
-            av.utils.err_check(-1)
-        except AVError as e:
+            av.error.err_check(-1)
+        except OSError as e:
             self.assertEqual(e.log, log)
         else:
             self.fail()
